---
sidebar_position: 3
---

# Високо ниво на концепции

`Тази документация е преведена автоматично и може да съдържа грешки. Не се колебайте да отворите Pull Request, за да предложите промени.`

LlamaIndex.TS ви помага да създавате приложения, базирани на LLM (например Q&A, чатбот) върху персонализирани данни.

В това ръководство за високо ниво на концепции ще научите:

- как LLM може да отговори на въпроси, използвайки вашите собствени данни.
- ключови концепции и модули в LlamaIndex.TS за създаване на ваша собствена заявка.

## Отговаряне на въпроси върху вашите данни

LlamaIndex използва двустепенен метод при използване на LLM с вашите данни:

1. **стъпка за индексиране**: подготовка на база от знания и
2. **стъпка за заявка**: извличане на съответния контекст от знанията, за да помогне на LLM да отговори на въпрос

![](./_static/concepts/rag.jpg)

Този процес е известен също като Retrieval Augmented Generation (RAG).

LlamaIndex.TS предоставя основния инструментариум, който прави и двете стъпки изключително лесни.

Нека изследваме всяка стъпка подробно.

### Стъпка на индексиране

LlamaIndex.TS ви помага да подготвите базата от знания с помощта на набор от конектори за данни и индекси.

![](./_static/concepts/indexing.jpg)

[**Data Loaders**](./modules/high_level/data_loader.md):
Конектор за данни (т.е. `Reader`) поема данни от различни източници на данни и формати на данни и ги превръща в просто представяне на `Document` (текст и прости метаданни).

[**Documents / Nodes**](./modules/high_level/documents_and_nodes.md): `Document` е общ контейнер за всякакъв вид данни - например PDF, изход от API или извлечени данни от база данни. `Node` е атомарната единица от данни в LlamaIndex и представлява "част" от източниковия `Document`. Това е богато представяне, което включва метаданни и връзки (към други възли), за да позволи точни и изразителни операции за извличане.

[**Data Indexes**](./modules/high_level/data_index.md):
След като сте поели данните си, LlamaIndex ви помага да индексирате данните във формат, който е лесен за извличане.

Под капака, LlamaIndex анализира суровите документи в промеждинни представяния, изчислява векторни вложения и съхранява данните в паметта или на диска.

"

### Стъпка за заявка

В стъпката за заявка, конвейерът за заявки извлича най-съответния контекст, даден на потребителска заявка,
и го предава на LLM (заедно със заявката), за да синтезира отговор.

Това дава на LLM актуални познания, които не са в неговите оригинални обучаващи данни,
(също така намалява халюцинацията).

Основното предизвикателство в стъпката за заявка е извличането, организирането и резонирането върху (потенциално много) бази от знания.

LlamaIndex предоставя модули, които могат да се комбинират и помагат за създаването и интегрирането на RAG конвейери за Q&A (заявки), чатбот (чат двигател) или като част от агент.

Тези строителни блокове могат да бъдат персонализирани, за да отразяват предпочитанията за ранжиране, както и да бъдат комбинирани, за да резонират върху множество бази от знания по структуриран начин.

![](./_static/concepts/querying.jpg)

#### Строителни блокове

[**Извличатели**](./modules/low_level/retriever.md):
Извличател дефинира как да се извлича ефективно съответния контекст от база от знания (т.е. индекс), когато се предостави заявка.
Конкретната логика за извличане се различава за различни индекси, като най-популярното е плътно извличане срещу векторен индекс.

[**Синтезатори на отговори**](./modules/low_level/response_synthesizer.md):
Синтезаторът на отговор генерира отговор от LLM, използвайки потребителска заявка и даден набор от извлечени текстови части.

"

#### Конвейери

[**Заявки**](./modules/high_level/query_engine.md):
Заявката е цялостен конвейер, който ви позволява да задавате въпроси относно вашите данни.
Тя приема заявка на естествен език и връща отговор, заедно с извлечения контекст, предаден на LLM.

[**Чат двигатели**](./modules/high_level/chat_engine.md):
Чат двигателът е цялостен конвейер за провеждане на разговор с вашите данни
(множество въпроси и отговори вместо единичен въпрос и отговор).

"
